/*
Description:
A divider tool that creates a horizontal lined divison or seperation.
Can be used to seperate list elements in a List View or create divisions on a page.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-divider.dart';

Usage:
- Defining the object for Divider

    CustomDividerParameters dividerParameters = new CustomDividerParameters(
        height: 1, thickness: 2, indent: 1, endIndent: 1, color: Colors.red);

- Object call for the widget

    customDivider(dividerParameters)
    
Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/consts.dart' as cons;

Widget customDivider(CustomDividerParameters dividerparams) {
  // Incase user doesn't pass any parameters
  if (dividerparams == null) {
    return Divider(
      height: cons.heightTwentyPixel,
      thickness: cons.thicknesssTwoPixel,
      indent: cons.indentOnePixel,
      endIndent: cons.endIndentOnePixel,
      color: mediumGreyThemeData().highlightColor,
    );
  } else {
    // Incase user passes all or limited number of parameters
    return Divider(
      height: (dividerparams.height == null)
          ? cons.heightTwentyPixel
          : dividerparams.height,
      thickness: (dividerparams.thickness == null)
          ? cons.thicknesssTwoPixel
          : dividerparams.thickness,
      indent: (dividerparams.indent == null)
          ? cons.indentOnePixel
          : dividerparams.indent,
      endIndent: (dividerparams.endIndent == null)
          ? cons.endIndentOnePixel
          : dividerparams.endIndent,
      color: (dividerparams.color == null)
          ? mediumGreyThemeData().highlightColor
          : dividerparams.color,
    );
  }
}
