/*
Description:

Dynamically creates an Outline Button material widget which responds to a press and long press.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-outlineButton.dart';

Usage:
The 'child' parameter accepts a widget to be displayed on the button and can be specified to be a Text, Icon, Image,etc.
The parameters such as shape,color,width,height,focusColor,hoverColor,highlightColor,splashColor,etc can be passed using the class 'FlatButtonParameters'.
onPress, & onLongPress callback functions can be passed which returns a 'true' value and can be used to define further actions to be performed on press & on long press respectively.
An Outline Button with default parameters is created if null is passed as Outlinebuttonparam.

- Defining the callback and Outline Button objects

onButtonPress(bool b){
      print(b);
    }

    onButtonLongPress(bool b){
      print(b);
    }
    Outlinebuttonparam outlineButtonObject = Outlinebuttonparam(child: Text('Submit'),shape: RoundedRectangleBorder(borderRadius: new BorderRadius.circular(10)),textColor: Colors.black,borderColor: Colors.black,color: Colors.orange);


- Object call for the widget

customOutlineButton(outlineButtonObject, onButtonPress, onButtonLongPress)

Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/consts.dart' as con;
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/theme.dart';

Widget customOutlineButton(Outlinebuttonparam param,
    void Function(bool) onPress, void Function(bool) onLongPress) {
  if (param == null && onPress == null && onLongPress == null) {
    return ButtonTheme(
      minWidth: con.heightHundred,
      height: con.heightTwenty,
      child: OutlineButton(
        borderSide: BorderSide(color: mediumGreyThemeData().buttonColor),
        disabledTextColor: mediumGreyThemeData().disabledColor,
        disabledBorderColor: mediumGreyThemeData().disabledColor,
        highlightedBorderColor: mediumGreyThemeData().highlightColor,
        autofocus: false,
        child: Text(con.buttonLabel),
        color: mediumGreyThemeData().buttonColor,
        textColor: null,
        splashColor: mediumGreyThemeData().splashColor,
        shape: con.outlineButtonShape,
        onPressed: () {},
        onLongPress: () {},
        hoverColor: mediumGreyThemeData().hoverColor,
        focusColor: mediumGreyThemeData().focusColor,
        highlightColor: mediumGreyThemeData().highlightColor,
      ),
    );
  } else {
    return ButtonTheme(
      minWidth: param.width != null ? param.width : con.heightHundred,
      height: param.height != null ? param.height : con.heightTwenty,
      child: OutlineButton(
        focusNode: param.focusNode,
        borderSide: BorderSide(
            color: (param.borderColor != null)
                ? param.borderColor
                : mediumGreyThemeData().buttonColor,
            width: (param.borderWidth != null)
                ? param.borderWidth
                : con.border_width,
            style: (param.borderStyle != null)
                ? param.borderStyle
                : BorderStyle.solid),
        disabledTextColor: (param.disabledTextColor != null)
            ? param.disabledTextColor
            : mediumGreyThemeData().disabledColor,
        disabledBorderColor: (param.disabledBorderColor != null)
            ? param.disabledBorderColor
            : mediumGreyThemeData().disabledColor,
        highlightedBorderColor: (param.highlightedBorderColor != null)
            ? param.highlightedBorderColor
            : mediumGreyThemeData().highlightColor,
        autofocus: (param.autofocus != null) ? param.autofocus : false,
        child: param.child != null ? param.child : Text(con.buttonLabel),
        color: (param.color != null)
            ? param.color
            : mediumGreyThemeData().buttonColor,
        textColor: param.textColor,
        shape: (param.shape != null) ? param.shape : con.outlineButtonShape,
        textTheme: param.textTheme,
        onPressed: () {
          return (onPress != null) ? onPress(true) : null;
        },
        onLongPress: () {
          return (onLongPress != null) ? onLongPress(true) : null;
        },
        focusColor: (param.focusColor != null)
            ? param.focusColor
            : mediumGreyThemeData().focusColor,
        highlightColor: (param.highlightColor != null)
            ? param.highlightColor
            : mediumGreyThemeData().highlightColor,
        hoverColor: (param.hoverColor != null)
            ? param.hoverColor
            : mediumGreyThemeData().hoverColor,
        splashColor: (param.splashColor != null)
            ? param.splashColor
            : mediumGreyThemeData().splashColor,
      ),
    );
  }
}
